Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5203)

Unified Diff: chrome/install_static/install_constants.h

Issue 2601443002: Remove multi-install from install_static. (Closed)
Patch Set: rebase onto position 442831 Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/install_static/google_chrome_install_modes.cc ('k') | chrome/install_static/install_details.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/install_static/install_constants.h
diff --git a/chrome/install_static/install_constants.h b/chrome/install_static/install_constants.h
index 1b79bceb11e6d970ff653d2340d56df3f74c17bf..a9b07a4e893bb1909b4881a0ea8624b33f26d724 100644
--- a/chrome/install_static/install_constants.h
+++ b/chrome/install_static/install_constants.h
@@ -58,8 +58,8 @@ struct InstallConstants {
// True if this mode supports system-level installs.
bool supports_system_level;
- // True if this mode supports multi-install.
- bool supports_multi_install;
+ // True if this mode supported the now-deprecated multi-install.
+ bool supported_multi_install;
};
} // namespace install_static
« no previous file with comments | « chrome/install_static/google_chrome_install_modes.cc ('k') | chrome/install_static/install_details.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698